==> jc-tke-client-1.1.284-sources.jar: com/xforceplus/ultraman/app/jctke/controller/SettlementOrderFeignApi.java <==
package com.xforceplus.ultraman.app.jctke.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-10-11
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.xforceplus.ultraman.app.jctke.entity.SettlementOrder;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface SettlementOrderFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/settlementOrder/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param settlementOrder ${table.comment}
   * @return R
   */
  @PostMapping("/settlementOrder/add")
  public R save(@RequestBody SettlementOrder settlementOrder);

  /**
   * 修改${table.comment}
   * @param settlementOrder ${table.comment}
   * @return R
   */
  @PostMapping("/settlementOrder/update")
  public R updateById(@RequestBody SettlementOrder settlementOrder);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/settlementOrder/del/{id}" )
  public R removeById(@PathVariable Long id);

}

==> jc-tke-client-1.1.346-sources.jar: com/xforceplus/ultraman/app/jctke/controller/SettlementOrderFeignApi.java <==
package com.xforceplus.ultraman.app.jctke.controller;


/**
 * ${table.comment}feign客户端
 *
 * @author ultraman
 * @date 2022-11-21
 */
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.GetMapping;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.api.R;
import org.apache.commons.lang3.StringUtils;
import com.xforceplus.ultraman.app.jctke.entity.SettlementOrder;
import lombok.AllArgsConstructor;
import org.springframework.stereotype.Controller;
import java.util.List;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;


@FeignClient(name = "jc-tke")
public interface SettlementOrderFeignApi {

  /**
   * 通过id查询${table.comment}
   * @param  id
   * @return R
   */
  @GetMapping("/settlementOrder/get/{id}" )
  public R getById(@PathVariable Long id);

  /**
   * 新增${table.comment}
   * @param settlementOrder ${table.comment}
   * @return R
   */
  @PostMapping("/settlementOrder/add")
  public R save(@RequestBody SettlementOrder settlementOrder);

  /**
   * 修改${table.comment}
   * @param settlementOrder ${table.comment}
   * @return R
   */
  @PostMapping("/settlementOrder/update")
  public R updateById(@RequestBody SettlementOrder settlementOrder);

  /**
   * 通过id删除${table.comment}
   * @param  id
   * @return R
   */
  @DeleteMapping("/settlementOrder/del/{id}" )
  public R removeById(@PathVariable Long id);

}
